package com.dragonsblaze.client.util;

import com.dragonsblaze.client.Rpc;
import com.dragonsblaze.client.Rpc.Callback;
import com.google.gwt.dom.client.Element;
import com.google.gwt.http.client.Request;
import com.google.gwt.http.client.Response;
import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONParser;
import com.google.gwt.json.client.JSONString;

public final class AnchorUtils
{
	private static final String ORIGINAL_HREF_ATTRIBUTE = "data-original-href";
	
	public static boolean expandHref(final Element element)
	{
		
		if (!isAnchorExternal(element))
			return false;

		final String href = element.getAttribute("href");

		if(!element.getAttribute(ORIGINAL_HREF_ATTRIBUTE).isEmpty())
			return false;

		LogUtils.log("anchor expanding: " + href);

		Rpc.call("expandURL", new JSONString(href), new Callback()
		{
			@Override
			public void onResponseReceived(Request request, Response response)
			{
				JSONObject responseObj = (JSONObject) JSONParser.parseStrict(response.getText());
				String finalURL = ((JSONString)responseObj.get("finalURL")).stringValue();
				LogUtils.log(finalURL);
				element.setAttribute(ORIGINAL_HREF_ATTRIBUTE, href);
				element.setAttribute("href", finalURL);
				if(!href.equals(finalURL))
					LogUtils.log("Updated link: " + href + " to " + finalURL);
			}
		});

		return true;
	}

	public static native boolean isAnchorExternal(Element anchor) /*-{
		return !!(anchor.host && anchor.host !== location.host)
	}-*/;

	public static native boolean isURLExternal(String url) /*-{
		var a = $wnd.document.createElement("a");
		a.href = url;
		return !!(a.host && a.host !== location.host)
	}-*/;

	public static native String getAnchorDestination(Element anchor) /*-{
		return anchor.pathname;
	}-*/;

	public static native void deactivateAnchor(Element anchor) /*-{
		$wnd.$(anchor).click(function() {
			return false
		});
	}-*/;
}
