package com.dragonsblaze.client.widget;

import com.google.gwt.core.client.GWT;
import com.google.gwt.http.client.Request;
import com.google.gwt.http.client.RequestBuilder;
import com.google.gwt.http.client.RequestCallback;
import com.google.gwt.http.client.RequestException;
import com.google.gwt.http.client.Response;
import com.google.gwt.http.client.URL;
import com.google.gwt.uibinder.client.UiConstructor;
import com.google.gwt.user.client.Command;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.HTML;

public class DynamicContentPanel extends Composite
{
	private String key;

	private HTML html = new HTML();

	private boolean loaded = false;

	private Command contentUpdateCommand;
	
	private static final String ERROR_MSG = "Unable to retrieve the data";

	@UiConstructor
	public DynamicContentPanel(String key)
	{
		initWidget(html);
		this.key = key;
	}

	@Override
	protected void onLoad()
	{
		if (!loaded) updateContent();
		super.onLoad();
	}

	public void setKey(String key)
	{
		loaded = loaded && this.key.equals(key);
		this.key = key;
	}

	public void onContentUpdate(Command command)
	{
		this.contentUpdateCommand = command;
	}

	private void setContent(String content)
	{
		html.setHTML(content);
		if(this.contentUpdateCommand != null)
			contentUpdateCommand.execute();
	}

	private void updateContent()
	{
		String url = "/content/" + key;

		RequestBuilder builder = new RequestBuilder(RequestBuilder.GET, URL.encode(url));

		try
		{
			builder.sendRequest(null, new RequestCallback()
			{
				public void onError(Request request, Throwable e)
				{
					GWT.log("XHR: Failure - " + e.getMessage());
					setContent(ERROR_MSG);
					loaded = false;
				}

				public void onResponseReceived(Request request, Response response)
				{
					if (response.getStatusCode() == 200 || response.getStatusCode() == 304)
					{
//						GWT.log("XHR: Success - " + response.getStatusCode());
						setContent(response.getText());
						loaded = true;
					}
					else
					{
						GWT.log("XHR: Failure - " + response.getStatusCode() + " - " + response.getStatusText());
						setContent(ERROR_MSG);
					}
				}
			});
		}
		catch (RequestException e)
		{
			GWT.log("XHR: Failure - " + e.getMessage());
			setContent(ERROR_MSG);
			loaded = false;
		}
	}
}
